@@ -10,7 +10,17 @@ import datetime
 import requests
 
 import py4web
-from py4web import __version__, action, abort, request, response, redirect, Translator, HTTP, URL
+from py4web import (
+    __version__,
+    action,
+    abort,
+    request,
+    response,
+    redirect,
+    Translator,
+    HTTP,
+    URL,
+)
 from py4web.core import Reloader, dumps, ErrorStorage, Session, Fixture
 from py4web.utils.factories import ActionFactory
 from pydal.validators import CRYPT
@@ -54,14 +64,13 @@ def get_commits(project):
     return commits
 
 
-
 def get_branches(project):
     """dictionary of git local branches for the project"""
     output = run("git branch", project)
-    branches = {"current" : "", "other" : []}
+    branches = {"current": "", "other": []}
     for line in output.split("\n"):
         if line.startswith("* "):
-            branches["current"] = line[2: ]
+            branches["current"] = line[2:]
         elif not line == "":
             branches["other"].append(line[2:])
     return branches
@@ -85,10 +94,12 @@ class Logged(Fixture):
 authenticated = ActionFactory(Logged(session))
 session_secured = action.uses(Logged(session))
 
-@action('version')
+
+@action("version")
 def version():
     return __version__
 
+
 if MODE in ("demo", "readonly", "full"):
 
     @action("index")
@@ -187,18 +198,18 @@ if MODE in ("demo", "readonly", "full"):
         if not os.path.exists(path):
             return {"status": "success", "payload": "App does not exist"}
         full_path = os.path.join(path, file_name)
-        if not full_path.startswith(path+os.sep):
+        if not full_path.startswith(path + os.sep):
             return {"status": "success", "payload": "Invalid path"}
         if os.path.exists(full_path):
             return {"status": "success", "payload": "File already exists"}
         parent = os.path.dirname(full_path)
         if not os.path.exists(parent):
             os.makedirs(parent)
-        with open(full_path, 'w') as fp:
+        with open(full_path, "w") as fp:
             if full_path.endswith(".html"):
                 fp.write('[[extend "layout.html"]]\nHello World!')
             elif full_path.endswith(".py"):
-                fp.write('# -*- coding: utf-8 -*-')
+                fp.write("# -*- coding: utf-8 -*-")
         return {"status": "success"}
 
     @action("walk/<path:path>")
@@ -332,12 +343,19 @@ if MODE in ("demo", "readonly", "full"):
             id = args[3] if len(args) == 4 else None
             policy = Policy()
             for table in db:
-                policy.set(table._tablename, 'GET', authorize=True,
-                           allowed_patterns=["**"], allow_lookup=True,
-                           fields=table.fields)
-                policy.set(table._tablename,'PUT', authorize=True, fields=table.fields)
-                policy.set(table._tablename,'POST', authorize=True, fields=table.fields)
-                policy.set(table._tablename,'DELETE', authorize=True)
+                policy.set(
+                    table._tablename,
+                    "GET",
+                    authorize=True,
+                    allowed_patterns=["**"],
+                    allow_lookup=True,
+                    fields=table.fields,
+                )
+                policy.set(table._tablename, "PUT", authorize=True, fields=table.fields)
+                policy.set(
+                    table._tablename, "POST", authorize=True, fields=table.fields
+                )
+                policy.set(table._tablename, "DELETE", authorize=True)
             data = action.uses(db, T)(
                 lambda: RestAPI(db, policy)(
                     request.method, args[2], id, request.query, request.json
@@ -456,7 +474,9 @@ if MODE == "full":
             return "Project is not a GIT repo"
         branches = get_branches(project)
         commits = get_commits(project)
-        return dict(commits=commits, checkout=checkout, project=project, branches=branches)
+        return dict(
+            commits=commits, checkout=checkout, project=project, branches=branches
+        )
 
     @authenticated.callback()
     def checkout(project, commit):
@@ -466,26 +486,26 @@ if MODE == "full":
         run("git checkout " + commit, project)
         Reloader.import_app(project)
 
-    @action("swapbranch/<project>" , method="POST")
+    @action("swapbranch/<project>", method="POST")
     @action.uses(Logged(session))
     def swapbranch(project):
         if not is_git_repo(project):
             raise HTTP(400)
 
-        branch = request.forms.get("branches") if request.forms.get("branches") else "master"
+        branch = (
+            request.forms.get("branches") if request.forms.get("branches") else "master"
+        )
         # swap branches then go back to gitlog so new commits load
-        checkout(project,branch)
-        redirect(URL('gitlog', project))
+        checkout(project, branch)
+        redirect(URL("gitlog", project))
         return diff2kryten(patch)
 
-
-
     @action("gitshow/<project>/<commit>")
     @action.uses(Logged(session), "gitshow.html")
     def gitshow(project, commit):
         if not is_git_repo(project):
             raise HTTP(400)
-        flag = request.params.get('showfull')
+        flag = request.params.get("showfull")
         opt = ""
         if flag == "true":
             opt = " -U9999"
