@@ -278,7 +278,12 @@ class Translator(pluralize.Translator, Fixture):
 
 
 class DAL(pydal.DAL, Fixture):
+
+    reconnect_on_request = True
+
     def on_request(self):
+        if self.reconnect_on_request:
+            self._adapter.reconnect()
         threadsafevariable.ThreadSafeVariable.restore(ICECUBE)
 
     def on_error(self):
@@ -1468,13 +1473,6 @@ def set_password(password, password_file):
     type=click.Choice(["off", "sync", "lazy"]),
     help="Watch python changes and reload apps automatically, modes: off (default), sync, lazy",
 )
-@click.option(
-    "--nogui",
-    is_flag=True,
-    default=False,
-    help="No Graphical User Interface",
-    show_default=True,
-)
 @click.option(
     "--ssl_cert", type=click.Path(exists=True), help="SSL certificate file for HTTPS"
 )
@@ -1503,8 +1501,6 @@ def run(**args):
                 "Dashboard is at: http://%s:%s/_dashboard"
                 % (args["host"], args["port"])
             )
-    if not args["nogui"]:
-        click.launch("http://%s:%s" % (args["host"], args["port"]))
 
     # Catch interrupts like Ctrl-C
     signal.signal(signal.SIGINT, keyboardInterruptHandler)
