@@ -8,7 +8,12 @@ class OAuth2Facebook(OAuth2):
     userinfo_url = "https://graph.facebook.com/me?fields=id,email,first_name,last_name"
     revoke_url = "https://accounts.google.com/me/permissions"
     default_scope = None
-    maps = {}  # TODO
+    maps = {
+        "email": "email",
+        "sso_id": "id",
+        "first_name": "first_name",
+        "last_name": "last_name",
+    }
 
     def revoke(self, token):
         requests.delete(self.revoke_url, headers={"Authorization": token})
